@@ -5,10 +5,10 @@ from numpy.testing import assert_array_equal, assert_equal
 from numpy import ma
 import tempfile, unittest, os, datetime
 
-nx=100; ydim=5; zdim=1
+nx=100; ydim=5; zdim=10
 nfiles = 10
 ninc = nx/nfiles
-files = [tempfile.mktemp(".nc") for nfile in range(nfiles)]
+files = [tempfile.NamedTemporaryFile(suffix='.nc', delete=False).name for nfile in range(nfiles)]
 data = randint(0,10,size=(nx,ydim,zdim))
 missval = 99
 data[::10] = missval
@@ -44,6 +44,7 @@ class VariablesTestCase(unittest.TestCase):
     def runTest(self):
         """testing multi-file dataset access"""
         f = MFDataset(self.files,check=True)
+        f.set_auto_maskandscale(True) # issue570
         assert f.history == 'created today'
         assert_array_equal(np.arange(0,nx),f.variables['x'][:])
         varin = f.variables['data']
@@ -61,12 +62,18 @@ class VariablesTestCase(unittest.TestCase):
         assert getattr(varin,'nonexistantatt',None) == None
         f.close()
 
+    def test_get_by_mfdataset(self):
+        """testing multi-file get_variables_by_attributes."""
+        f = MFDataset(self.files,check=True)
+        assert f.get_variables_by_attributes(axis='T') == []
+        f.get_variables_by_attributes(units='zlotys')[0] == f['x']
+        f.close()
 
 class NonuniformTimeTestCase(unittest.TestCase):
     ninc = 365
     def setUp(self):
 
-        self.files = [tempfile.mktemp(".nc") for nfile in range(2)]
+        self.files = [tempfile.NamedTemporaryFile(suffix='.nc', delete=False).name for nfile in range(2)]
         for nfile,file in enumerate(self.files):
             f = Dataset(file,'w',format='NETCDF4_CLASSIC')
             f.createDimension('time',None)
